@@ -3,6 +3,11 @@
 
 #include <QtGui/QMainWindow>
 
+class PuntateForm;
+class SocialNetwork;
+class Credits;
+class OptionsForm;
+
 namespace Ui {
     class MainWindow;
 }
@@ -38,78 +43,28 @@ private slots:
 
     void on_telecupole_clicked();
 
-    void on_browserfb_clicked();
-
-    void on_browsertw_clicked();
-
-    void on_actionContattami_triggered();
-
     void on_actionYoutube_triggered();
 
-    void on_pushButton_22_clicked();
-
-    void on_stream1_clicked();
-
-    void on_down2_clicked();
-
-    void on_stream2_clicked();
-
-    void on_down3_clicked();
-
-    void on_stream3_clicked();
-
-    void on_down4_clicked();
-
-    void on_stream4_clicked();
-
-    void on_down5_clicked();
-
-    void on_stream5_clicked();
-
-    void on_down6_clicked();
-
-    void on_stream6_clicked();
-
-    void on_down7_clicked();
-
-    void on_stream7_clicked();
-
-    void on_down8_clicked();
-
-    void on_stream8_clicked();
-
-    void on_down9_clicked();
-
-    void on_stream9_clicked();
-
-    void on_down10_clicked();
-
-    void on_stream10_clicked();
-
-    void on_down11_clicked();
-
-    void on_stream11_clicked();
-
-    void on_down12_clicked();
-
-    void on_stream12_clicked();
-
-    void on_actionAbout_triggered();
-
     void on_actionOpzioni_triggered();
 
-    void on_down13_clicked();
-
-    void on_stream13_clicked();
-
     void on_actionServizioPubblico_Online_triggered();
 
     void on_actionRicorda_un_amico_triggered();
 
     void on_actionDonazione_triggered();
 
+    void on_actionPuntate_triggered();
+
+    void on_actionSocial_Network_triggered();
+
+    void on_actionCredits_triggered();
+
 private:
     Ui::MainWindow *ui;
+    PuntateForm *puntateForm;
+    SocialNetwork *socialNetwork;
+    Credits *credits;
+    OptionsForm *optionsForm;
 };
 
 #endif // MAINWINDOW_H
